<?php declare(strict_types=1);
/*
 You may not change or alter any portion of this comment or credits of
 supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit
 authors.

 This program is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * Module: XoopsFaq
 *
 * Module Configuration file
 *
 * @author          John Neill
 * @author          XOOPS Module Development Team
 * @copyright       https://xoops.org 2001-2017 &copy; XOOPS Project
 * @license         https://www.gnu.org/licenses/gpl-2.0.html GNU Public License
 */
defined('XOOPS_ROOT_PATH') || exit('Restricted access');

require_once __DIR__ . '/preloads/autoloader.php';

$moduleDirName      = basename(__DIR__);
$moduleDirNameUpper = \mb_strtoupper($moduleDirName);

// Module configs
$modversion = [
    'version'             => '2.1.0',
    'module_status'       => 'beta.1',
    'release_date'        => '2023/05/25',
    'name'                => _MI_XOOPSFAQ_NAME,
    'description'         => _MI_XOOPSFAQ_DESC,
    'author'              => 'John Neill, Kazumi Ono',
    'credits'             => 'The Xoops Module Development Team, ZySpec, Mamba, Geekwright',
    'license'             => 'GNU GPL 2.0',
    'license_url'         => 'www.gnu.org/licenses/gpl-2.0.html/',
    'official'            => 0,
    'image'               => 'assets/images/logoModule.png',
    'dirname'             => basename(__DIR__),

    // Local path icons
    'modicons16'          => 'assets/images/icons/16',
    'modicons32'          => 'assets/images/icons/32',

    //about
    'author_website_url'  => 'https://xoops.org',
    'author_website_name' => 'XOOPS',
    'module_website_url'  => 'https://xoops.org',
    'module_website_name' => 'XOOPS',
    'min_php'             => '7.4',
    'min_xoops'           => '2.5.10',
    'min_db'              => ['mysql' => '5.5'],
    'min_admin'           => '1.2',
];

// ------------------- Help files ------------------- //
$modversion['help']        = 'page=help';
$modversion['helpsection'] = [
    ['name' => _MI_XOOPSFAQ_HELP_OVERVIEW, 'link' => 'page=help'],
    ['name' => _MI_XOOPSFAQ_HELP_TIPS, 'link' => 'page=tips'],
    ['name' => _MI_XOOPSFAQ_DISCLAIMER, 'link' => 'page=disclaimer'],
    ['name' => _MI_XOOPSFAQ_LICENSE, 'link' => 'page=license'],
    ['name' => _MI_XOOPSFAQ_SUPPORT, 'link' => 'page=support'],
];

// ------------------- Mysql -----------------------------
$modversion['sqlfile']['mysql'] = 'sql/mysql.sql';
// ------------------- Tables ----------------------------
$modversion['tables'] = [
    'xoopsfaq_contents',
    'xoopsfaq_categories',
];

// ------------------- Install/Update -------------------
// Scripts to run upon installation or update
$modversion['onInstall'] = 'include/oninstall.php';
$modversion['onUpdate']  = 'include/onupdate.php';

// Module Admin
$modversion['hasAdmin']   = 1;
$modversion['adminindex'] = 'admin/index.php';
$modversion['adminmenu']  = 'admin/menu.php';

/*
 * Admin Menu
 * Set to:
 *    0 if you do not want to display menu generated by system module
 *    1 if you want to display menu generated by system module
 */
$modversion['system_menu'] = 1;

// Module Main
$modversion['hasMain'] = 1;

// ------------------- Blocks ------------------- //
$modversion['blocks'] = [
    [
        'file'        => 'xoopsfaq_rand.php',
        'name'        => _MI_XOOPSFAQ_BNAME1,
        'description' => _MI_XOOPSFAQ_BNAME1_DESC,
        'show_func'   => 'b_xoopsfaq_random_show',
        'edit_func'   => 'b_xoopsfaq_rand_edit',
        'options'     => '100|0',
        'template'    => 'xoopsfaq_block_rand.tpl',
    ],

    [
        'file'        => 'xoopsfaq_recent.php',
        'name'        => _MI_XOOPSFAQ_BNAME2,
        'description' => _MI_XOOPSFAQ_BNAME2_DESC,
        'show_func'   => 'b_xoopsfaq_recent_show',
        'edit_func'   => 'b_xoopsfaq_recent_edit',
        'options'     => '10|100|1|0',
        'template'    => 'xoopsfaq_block_recent.tpl',
    ],

    [
        'file'        => 'xoopsfaq_category.php',
        'name'        => _MI_XOOPSFAQ_BNAME3,
        'description' => _MI_XOOPSFAQ_BNAME3_DESC,
        'show_func'   => 'b_xoopsfaq_category_show',
        'edit_func'   => 'b_xoopsfaq_category_edit',
        'options'     => '1',
        'template'    => 'xoopsfaq_block_category.tpl',
    ],
];

// Module Search
$modversion['hasSearch']      = 1;
$modversion['search']['file'] = 'include/search.inc.php';
$modversion['search']['func'] = 'xoopsfaq_search';

// Module Templates
$modversion['templates'] = [
    [
        'file'        => "{$moduleDirName}_index.tpl",
        'description' => _MI_XOOPSFAQ_TPL_INDEX_DESC,
    ],

    [
        'file'        => "{$moduleDirName}_category.tpl",
        'description' => _MI_XOOPSFAQ_TPL_CATEGORY_DESC,
    ],
];

// Module Comments
$modversion['hasComments'] = 1;
$modversion['comments']    = [
    'itemName' => 'cat_id',
    'pageName' => 'index.php',
];

// Module Configs
xoops_load('XoopsEditorHandler');
$editorHandler = XoopsEditorHandler::getInstance();
$editorList    = array_flip($editorHandler->getList());

$modversion['config'][] = [
    'name'        => 'use_wysiwyg',
    'title'       => '_MI_XOOPSFAQ_EDITORS',
    'description' => '_MI_XOOPSFAQ_EDITORS_DESC',
    'formtype'    => 'select',
    'valuetype'   => 'text',
    'options'     => $editorList,
    'default'     => 'dhtmltextarea',
];

$modversion['config'][] = [
    'name'        => 'generate_jsonld',
    'title'       => 'CO_' . $moduleDirNameUpper . '_' . 'GENERATE_JSONLD',
    'description' => 'CO_' . $moduleDirNameUpper . '_' . 'GENERATE_JSONLD_DESC',
    'formtype'    => 'yesno',
    'valuetype'   => 'int',
    'default'     => 1,
];

/**
 * Make Sample button visible?
 */
$modversion['config'][] = [
    'name'        => 'displaySampleButton',
    'title'       => 'CO_' . $moduleDirNameUpper . '_' . 'SHOW_SAMPLE_BUTTON',
    'description' => 'CO_' . $moduleDirNameUpper . '_' . 'SHOW_SAMPLE_BUTTON_DESC',
    'formtype'    => 'yesno',
    'valuetype'   => 'int',
    'default'     => 1,
];

/**
 * Show Developer Tools?
 */
$modversion['config'][] = [
    'name'        => 'displayDeveloperTools',
    'title'       => 'CO_' . $moduleDirNameUpper . '_' . 'SHOW_DEV_TOOLS',
    'description' => 'CO_' . $moduleDirNameUpper . '_' . 'SHOW_DEV_TOOLS_DESC',
    'formtype'    => 'yesno',
    'valuetype'   => 'int',
    'default'     => 0,
];
